@@ -22,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Сталася невідома помилка",
     "File could not be uploaded" : "Неможливо завантажити файл",
     "Uploading …" : "Завантаження…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber} із {total})",
+    "Uploading … ({currentNumber}/{total})" : "Завантаження ... ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Завантаження цього елемента не підтримується",
     "Target folder does not exist any more" : "Каталог призначення більше не дійсний",
@@ -32,13 +34,14 @@ OC.L10N.register(
     "Move" : "Перемістити",
     "Copy" : "Копіювати",
     "Choose target folder" : "Виберіть каталог призначення",
+    "Set reminder" : "Встановити нагадування",
     "Edit locally" : "Редагувати локально",
     "Open" : "Відкрити",
     "Delete file" : "Вилучити файл",
     "Delete folder" : "Вилучити каталог",
     "Disconnect storage" : "Від’єднати сховище",
     "Leave this share" : "Вийти зі спільного доступу",
-    "Could not load info for file \"{file}\"" : "Не вдалося завантажити дані про файл \"{file}\"",
+    "Could not load info for file \"{file}\"" : "Не вдалося отримати дані щодо файлу \"{file}\"",
     "Files" : "Файли",
     "Details" : "Деталі",
     "Please select tag(s) to add to the selection" : "Виберіть мітки, які ви додасте до вибраного",
@@ -50,10 +53,10 @@ OC.L10N.register(
     "This operation is forbidden" : "Операцію заборонено",
     "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступний, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
     "Storage is temporarily not available" : "Сховище тимчасово недоступне",
-    "Could not move \"{file}\", target exists" : "Не вдається перемістити файл \"{file}\", оскільк він існує в точці призначення",
+    "Could not move \"{file}\", target exists" : "Не вдалося перемістити файл \"{file}\", оскільки файл з таким ім'ям вже присутній",
     "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
     "copy" : "копія",
-    "Could not copy \"{file}\", target exists" : "Не вдається скопіювати файл \"{file}\", оскільки він вже присутній в точці призначення",
+    "Could not copy \"{file}\", target exists" : "Не вдалося скопіювати файл \"{file}\", оскільки файл з таким ім'ям вже присутній",
     "Could not copy \"{file}\"" : "Неможливо скопіювати \"{file}\"",
     "Copied {origin} inside {destination}" : "Скопійовано {origin} до {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} та {nbfiles} інших файлів скопійовано до {destination}",
@@ -63,8 +66,8 @@ OC.L10N.register(
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{targetName}\" вже використовується у каталозі \"{dir}\". Будь-ласка, виберіть іншу назву.",
     "Could not rename \"{fileName}\"" : "Неможливо перейменувати \"{fileName}\"",
     "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки він вже існує.",
-    "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки він вже існує.",
+    "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки файл з таким ім'ям вже присутній.",
+    "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки каталог з таким ім'ям він вже присутній.",
     "Could not fetch file details \"{file}\"" : "Неможливо отримати деталі файлу \"{file}\"",
     "Error deleting file \"{fileName}\"." : "Помилка вилучення файлу \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
@@ -78,6 +81,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["включаючи %n прихований","включаючи %n прихованих","включаючи %n прихованих","включно %n прихованих"],
     "You do not have permission to upload or create files here" : "У вас відсутні повноваження для завантаження або створення файлів тут",
     "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів","Завантаження %n файлів"],
+    "New" : "Створити",
     "New file/folder menu" : "Меню з новим файлом/каталогом",
     "Select file range" : "Вибрати кілька файлів",
     "{used}%" : "{used}%",
@@ -97,23 +101,21 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ваше сховище майже заповнено ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\""],
     "View in folder" : "Переглянути у каталозі",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Пряме посилання скопійовано (застосовується у разі, якщо користувач має доступ до ресурсу)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Пряме посилання було скопійовано (дійсне лише для користувачів, які мають відповідні права доступу)",
     "Path" : "Шлях",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт(ів)"],
     "Favorited" : "Із зірочкою",
     "Favorite" : "Додати зірочку",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копіювати пряме посилання (користувачі мають мати доступ до цього файлу чи каталогу)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Копіювати пряме посилання (дійсне лише для користувачів, які мають відповідні права доступу)",
     "New folder" : "Новий каталог",
     "Create new folder" : "Створити новий каталог",
     "Upload file" : "Завантажити файл",
     "Recent" : "Останні",
-    "This file has the tag {tag}" : "Цей файл має мітку {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Цей файл має мітку {firstTags} та {lastTag}",
     "Not favorited" : "Без зірочки",
     "Remove from favorites" : "Прибрати зірочку",
     "Add to favorites" : "Додати зірочку",
     "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
-    "Added to favorites" : "Вподобано",
+    "Added to favorites" : "Додано зірочку",
     "Removed from favorites" : "Вилучено зірочку",
     "You added {file} to your favorites" : "Ви додали зірочку для {file}",
     "You removed {file} from your favorites" : "Ви прибрали зірочку для {file}",
@@ -123,9 +125,9 @@ OC.L10N.register(
     "Changed by {user}" : "Змінено користувачем {user}",
     "Deleted by {user}" : "Вилучено користувачем {user}",
     "Restored by {user}" : "Відновлено користувачем {user}",
-    "Renamed by {user}" : "Перейменовано {user}",
+    "Renamed by {user}" : "Перейменовано користувачем {user}",
     "Moved by {user}" : "Переміщено користувачем {user}",
-    "\"remote user\"" : "\"віддалений користувач\"",
+    "\"remote account\"" : "\"віддалений обліковий запис\"",
     "You created {file}" : "Ви створили {file}",
     "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
     "{user} created {file}" : "{user} створив(-ла) файл {file}",
@@ -151,132 +153,245 @@ OC.L10N.register(
     "{user} renamed {oldfile} to {newfile}" : "{user} перейменував(-ла) {oldfile} у {newfile}",
     "You moved {oldfile} to {newfile}" : "Ви перемістили {oldfile} до {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} перемістив(-ла) {oldfile} до {newfile}",
-    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл було додано або вилучено з ваших <strong>вподобаних</strong> документів",
+    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл було додано або вилучено з ваших документів <strong>із зірочкою</strong>",
     "A file or folder has been <strong>changed</strong>" : "Файл або каталог було <strong> змінено </strong>",
-    "A favorite file or folder has been <strong>changed</strong>" : "Вподобаний файли або каталог було <strong>змінено</strong>",
-    "All files" : "Усі файли",
+    "A favorite file or folder has been <strong>changed</strong>" : "Файл або каталог із зірочкою було <strong>змінено</strong>",
+    "Failed to authorize" : "Не вдалося авторизуватися",
+    "Invalid folder path" : "Недійсний шлях до каталогу",
+    "Folder not found" : "Каталог не знайдено",
     "Upload (max. %s)" : "Завантаження (макс. %s)",
+    "Files compatibility" : "Сумісність файлів",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр. Linux, macOS) дозволені.",
+    "Enforce Windows compatibility" : "Увімкнути сумісність із Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Це унеможливить використання імен файлів, які не сумісні з системами Windows, напр., використанння зарезервованих імен або спеціальних символів. Зауважте, що це не обмежить сумісність за регістром символів.",
     "Accept" : "Прийняти",
     "Reject" : "Відхилити",
-    "Incoming ownership transfer from {user}" : "Запит від користувача {user} на передачу прав власності",
-    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Прийняти {path}?\n\nУвага: процес передачі після прийняття може тривати до 1 години.",
+    "Incoming ownership transfer from {user}" : "Запит від користувача {user} на передавання прав власника",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Прийняти {path}?\n\nУвага: Процес передавання після прийняття запиту може тривати до 1 години.",
+    "Ownership transfer denied" : "Перенесення прав власності відхилено",
+    "Your ownership transfer of {path} was denied by {user}." : "Перенесення прав на ваші дані {path} відхилено користувачем {user}.",
     "Ownership transfer failed" : "Не вдалося передати право власності",
-    "Your ownership transfer of {path} to {user} failed." : "Передача вашого права власності на {path} користувачеві {user} не вдалася.",
-    "The ownership transfer of {path} from {user} failed." : "Передача прав власника на {path} від користувача {user} не вдалася.",
+    "Your ownership transfer of {path} to {user} failed." : "Не вдалося перадати ваші права власника на {path} користувачеві {user}.",
+    "The ownership transfer of {path} from {user} failed." : "Не вдалося передати права власника на {path} від користувача {user}.",
     "Ownership transfer done" : "Право власності передано",
-    "Your ownership transfer of {path} to {user} has completed." : "Передачу ваших прав власника на {path} користувачеві {user} виконано.",
-    "The ownership transfer of {path} from {user} has completed." : "Передачу прав власника на {path} від користувача {user} завершено.",
+    "Your ownership transfer of {path} to {user} has completed." : "Ваші права власника на {path} успішно передано користувачеві {user}.",
+    "The ownership transfer of {path} from {user} has completed." : "Завершено передавання права власника на {path} від користувача {user}.",
     "in %s" : "в %s",
+    "Transferred from %1$s on %2$s" : "Перенесено від %1$s до %2$s",
     "File Management" : "Керування файлами",
-    "Reload current directory" : "Перевантажити поточний каталог",
+    "Current directory path" : "Шлях до поточного каталогу",
+    "Reload current directory" : "Перезавантажити поточний каталог",
     "Go to the \"{dir}\" directory" : "Перейти до каталогу \"{dir}\"",
-    "Select the row for {displayName}" : "Виберіть рядок для {displayName}",
+    "Drag and drop files here to upload" : "Перетягніть файли сюди для завантаження",
+    "Your have used your space quota and cannot upload files anymore" : "Ви вже використали квоту на місце та не можете завантажувати файли",
+    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для завантаження або створення файлів тут",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" успішно виконано",
+    "\"{displayName}\" action failed" : "Не вдалося виконати \"{displayName}\"",
+    "Toggle selection for file \"{displayName}\"" : "Перемкнути вибір для файлу \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Перемкнути вибір для каталогу \"{displayName}\"",
+    "File is loading" : "Завантаження файлу",
+    "Folder is loading" : "Завантаження каталогу",
     "Rename file" : "Перейменувати файл",
-    "File name" : "Ім'я файлу",
-    "A long time ago" : "Давно",
-    "Download file {name}" : "Завантажити файл {name}",
-    "\"{displayName}\" action executed successfully" : "Дію \"{displayName}\" успішно виконано",
-    "\"{displayName}\" action failed" : "Дію \"{displayName}\" не вдалося виконати",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" є недозволеним типом файлу.",
-    "{newName} already exists." : "{newName} вже присутній.",
-    "Name cannot be empty" : "Ім'я не може бути порожнім",
-    "Another entry with the same name already exists" : "Ще один запис з такою же назвою присутній.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" у \"{newName\"",
+    "Filename" : "Ім'я файлу",
+    "Folder name" : "Назва каталогу",
+    "This node is unavailable" : "Цей вузол не доступний",
+    "Another entry with the same name already exists." : "Інший запис з таким же ім'ям вже присутній",
+    "Invalid filename." : "Недійсне ім'я файлу.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" на \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не вдалося перейментувати \"{oldName}\", оскільки він вже відсутній",
-    "The name \"{newName}\"\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{newName}\" вже використовується каталогом \"{dir}\". Виберіть інше ім'я.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{newName}\" вже використовується у каталозі \"{dir}\". Виберіть інше ім'я.",
     "Could not rename \"{oldName}\"" : "Не вдалося перейменувати \"{oldName}\"",
+    "Clear filter" : "Очистити фільтр",
+    "Type" : "Тип",
+    "Active filters" : "Активні фільтри",
+    "Remove filter" : "Вилучити фільтр",
     "Total rows summary" : "Загалом рядків",
-    "Select all" : "Вибрати все",
-    "Unselect all" : "Зняти вибір",
+    "Toggle selection for all files and folders" : "Перемкнути вибір для всіх файлів та каталогів",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" не показується в окремих елементах",
-    "\"{displayName}\" batch action executed successfully" : "Пакетну дію \"{displayName}\" виконано успішно",
-    "ascending" : "за зростанням",
-    "descending" : "за спаданням",
-    "Sort list by {column} ({direction})" : "Впорядкувати список за {column} ({direction})",
+    "\"{displayName}\" batch action executed successfully" : "Операцію \"{displayName}\" успішно виконано",
+    "{count} selected" : "{count} вибрано",
     "List of files and folders." : "Список файлів та каталогів",
+    "Column headers with buttons are sortable." : "Назви стовпців з кнопками можна впорядковувати",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Список не подається повністю з міркувань обчислювальних потужностей. Файли показуватимуться під час прокручування списку.",
-    "Storage informations" : "Інформація про сховище",
+    "File not found" : "Файл не знайдено",
+    "Storage information" : "Інформація про сховище",
+    "Storage quota" : "Квота сховища",
     "{usedQuotaByte} used" : "{usedQuotaByte} використано",
     "{relative}% used" : "{relative}% використано",
     "Could not refresh storage stats" : "Неможливо оновити статистику сховища",
-    "Transfer ownership of a file or folder" : "Передача прав власника на файл або каталог",
-    "Choose file or folder to transfer" : "Виберіть файл або каталог для передачі",
+    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані!",
+    "Create" : "Створити",
+    "This name is already in use." : "Це ім'я вже використовується",
+    "Fill template fields" : "Заповнити поля шаблону",
+    "Submitting fields…" : "Поля для надсилання...",
+    "Submit" : "Відправити",
+    "Transfer ownership of a file or folder" : "Передавання прав власника на файл або каталог",
+    "Choose file or folder to transfer" : "Виберіть файл або каталог для передавання",
     "Change" : "Змінити",
     "New owner" : "Новий власник",
-    "Choose a file or folder to transfer" : "Виберіть файл або каталог для передачі",
+    "Choose a file or folder to transfer" : "Виберіть файл або каталог для передавання",
     "Transfer" : "Передати",
     "Transfer {path} to {userid}" : "Передати {path} користувачеві {userid}",
     "Invalid path selected" : "Вибрано неправильний шлях",
     "Unknown error" : "Невідома помилка",
-    "Ownership transfer request sent" : "Запит на передачу прав власності надіслано",
+    "Ownership transfer request sent" : "Запит на передавання прав власника надіслано",
     "Cannot transfer ownership of a file or folder you do not own" : "Неможливо передати права власності на файл або каталог, якими ви не володієте",
     "Select file or folder to link to" : "Виберіть файл або каталог, до якого потрібно застосувати посилання",
-    "Loading current folder" : "Завантаження поточного каталогу",
+    "Choose file" : "Вибрати файл",
+    "Choose {file}" : "Виберіть {file}",
+    "Loading current folder" : "Отримання поточного каталогу",
     "No files in here" : "Тут немає файлів",
     "Upload some content or sync with your devices!" : "Завантажте вміст або синхронізуйтеся з вашими пристроями!",
     "Go to the previous folder" : "До попереднього каталогу",
     "Go back" : "Повернутися назад",
-    "Open the files app settings" : "Перейти до налаштувань застосунку файлів",
+    "Share" : "Поширити",
+    "Shared by link" : "Доступ за посиланням",
+    "Shared" : "Спільне",
+    "Switch to list view" : "У вигляді списку",
+    "Switch to grid view" : "У вигляді сітки",
+    "Upload was cancelled by user" : "Завантаження скасовано користувачем",
+    "Error during upload: {message}" : "Помилка під час завантаження: {message}",
+    "Error during upload, status code {status}" : "Помилка під час завантаження, код стану {status}",
+    "Unknown error during upload" : "Невідома помилка під час завантаження",
+    "Filter filenames…" : "Фільтрувати за ім'ям файлу...",
+    "Views" : "Подання",
     "Files settings" : "Налаштування",
     "File cannot be accessed" : "Неможливо отримати доступ до файлу",
-    "You might not have have permissions to view it, ask the sender to share it" : "Ймовірно у вас відсутні права на перегляд. Попросіть відправника поділитися доступом.",
-    "Sort favorites first" : "Спочатку впорядковувати вподобані",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не вдалося знайти файл або у вас відсутній дозвіл на перегляд файлу. Попросіть поділитися цим файлом.",
+    "Your files" : "Ваші файли",
+    "Open in files" : "Відкрити у файлах",
+    "Sort favorites first" : "Спочатку впорядковувати із зірочкою",
+    "Sort folders before files" : "Впорядковувати каталоги поререду файлів",
     "Show hidden files" : "Показувати приховані файли",
     "Crop image previews" : "Попередній перегляд перед кадруванням",
+    "Enable the grid view" : "Увімкнути подання сіткою",
+    "Enable folder tree" : "Увімкнути дерево каталогів",
     "Additional settings" : "Додатково",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL-адреса WebDAV",
     "Copy to clipboard" : "Копіювати до буферу обміну",
     "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Якщо увімкнено двофакторної авторизацію, вам потрібно створити та використовувати окремий пароль на застосунок. Для цього клацніть тут.",
     "Clipboard is not available" : "Буфер обміну недоступний",
     "WebDAV URL copied to clipboard" : "Послиання WebDAV скопійовано до буферу обміну",
     "Unable to change the favourite state of the file" : "Неможливо змінити стан \"зірочка\" для цього файла",
-    "Error while loading the file data" : "Помилка під час завантаження даних про файл",
+    "Error while loading the file data" : "Помилка під час отримання даних щодо файлу",
     "Pick a template for {name}" : "Вибрати шаблон для {name}",
-    "Create" : "Створити",
     "Create a new file with the selected template" : "Створити новий файл на основі вибраного шаблону",
     "Creating file" : "Створення файлу",
     "Blank" : "Порожньо",
     "Unable to create new file from template" : "Неможливо створити новий файл з шаблону",
+    "Deletion cancelled" : "Вилучення скасовано",
     "Delete permanently" : "Вилучити назавжди",
+    "Delete and unshare" : "Вилучити та прибрати спільний доступ",
+    "Leave these shares" : "Вийти зі спільного доступу",
+    "Disconnect storages" : "Від'єднати сховища",
+    "Delete files" : "Вилучити файли",
+    "Delete folders" : "Вилучити каталоги",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Ви намагаєтеся назавжли вилучити {count} ресурс","Ви намагаєтеся назавжли вилучити {count} ресурси","Ви намагаєтеся назавжли вилучити {count} ресурсів","Ви намагаєтеся назавжли вилучити {count} ресурсів"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Ви намагаєтеся вилучити {count} ресурс","Ви намагаєтеся вилучити {count} ресурси","Ви намагаєтеся  вилучити {count} ресурсів","Ви намагаєтеся вилучити {count} ресурсів"],
+    "Confirm deletion" : "Підтвердіть вилучення",
+    "Cancel" : "Скасувати",
+    "Edit file locally" : "Редагувати файл на пристрої",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Зараз файл можна бути відкривати на пристрої. Якщо така можливість відсутня, переконайтеся, що настільний клієнт встановлено на вашій системі.",
+    "Retry local edit" : "Спробувати повторно редагування на пристрої",
+    "Edit online" : "Редагувати в онлайні",
+    "Destination is not a folder" : "Місце призначення не є каталогом",
+    "This file/folder is already in that directory" : "Такий файл чи каталог вже присутні в цьому каталозі",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможливо перемістити файл чи каталог до самого себе або у цей саме підкаталог",
+    "(copy)" : "(копія)",
+    "(copy %n)" : "(копія %n)",
+    "Move cancelled" : "Переміщення скасовано",
+    "A file or folder with that name already exists in this folder" : "Файл чи каталог з таким ім'ям вже присутній в цьому каталозі",
+    "The files are locked" : "Файли заблоковано",
+    "The file does not exist anymore" : "Цей файл більше недоступний",
+    "Choose destination" : "Виберіть каталог призначення",
+    "Copy to {target}" : "Копіювати до {target}",
+    "Move to {target}" : "Перемістити до {target}",
+    "Move or copy operation failed" : "Не вдалося скопіювати або перемістити",
+    "Cancelled move or copy of \"{filename}\"." : "Скасовано переміщення або копіювання \"{filename}\".",
+    "Cancelled move or copy operation" : "Переміщення або копіювання скасовано",
     "Open folder {displayName}" : "Відкрити каталог {displayName}",
     "Open in Files" : "Відкрити у Файлах",
     "Open details" : "Показати деталі",
-    "Set up templates folder" : "Встановити каталог з шаблонами",
-    "Templates" : "Шаблони",
-    "Create new templates folder" : "Створіть нову папку шаблонів",
+    "Today" : "Сьогодні",
+    "Last 7 days" : "За останні 7 днів",
+    "Last 30 days" : "За останні 30 днів",
+    "This year ({year})" : "Цього року ({year})",
+    "Last year ({year})" : "Останнього року ({year})",
+    "Documents" : "Документи",
+    "Spreadsheets" : "Електронні таблиці",
+    "Presentations" : "Презентації",
+    "PDFs" : "Файли PDF",
+    "Folders" : "Каталоги",
+    "Audio" : "Аудіо",
+    "Photos and images" : "Світлини та зображення",
+    "Videos" : "Відео",
+    "New folder creation cancelled" : "Створення нового каталогу скасовано",
+    "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
     "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
-    "List of favorites files and folders." : "Список вподобаних файлів та каталогів.",
-    "No favorites yet" : "Поки немає вподобаного",
-    "Files and folders you mark as favorite will show up here" : "Файли та каталоги, які ви вподобали, з’являться тут",
+    "Create templates folder" : "Створити каталог для шаблонів",
+    "Templates" : "Шаблони",
+    "New template folder" : "Новий каталог шаблонів",
+    "In folder" : "У каталозі",
+    "Search in folder: {folder}" : "Шукати у каталозі: {folder}",
+    "One of the dropped files could not be processed" : "Один із завантажених файлів не вдалося обробити",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш бравзер не підтримує Filesystem API. Каталоги не буде завантажено",
+    "No files to upload" : "Відсутні файли для завантаження",
+    "Unable to create the directory {directory}" : "Неможливо створити каталог {directory}",
+    "Some files could not be uploaded" : "Не вдалося завантажити окремі файли",
+    "Files uploaded successfully" : "Файли успішно завантажено",
+    "No files to process" : "Відсутні файли для обробки",
+    "Some files could not be copied" : "Неможливо скопіювати окремі файли",
+    "Some files could not be moved" : "Окремі файли неможливо перемістити",
+    "Files copied successfully" : "Файли успішно скопійовано",
+    "Files moved successfully" : "Файли успішно переміщено",
+    "Conflicts resolution skipped" : "Пропущено розв'язання конфліктів",
+    "Upload cancelled" : "Завантаження скасовано",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} каталог","{folderCount} каталоги","{folderCount} каталогів","{folderCount} каталогів"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файли","{fileCount} файлів","{fileCount} файлів"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 файл та {folderCount} каталог","1 файл та {folderCount} каталоги","1 файл та {folderCount} каталогів","1 файл та {folderCount} каталогів"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл та 1 каталог","{fileCount} файли та 1 каталог","{fileCount} файлів та 1 каталог","{fileCount} файлів та 1 каталог"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} файлів та {folderCount} каталогів",
+    "Filename must not be empty." : "Імена файлів не мають бути порожні.",
+    "\"{char}\" is not allowed inside a filename." : "Символ \"{char}\" не дозволено у імені файлу.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" є зарезервованим ім'ям і не дозволяється у іменах файлів.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" не є дозволеним типом файлів.",
+    "Filenames must not end with \"{extension}\"." : "Імена файлів не мають закінчуватися на \"{extension}\".",
+    "List of favorites files and folders." : "Список файлів та каталогів із зірочкою.",
+    "No favorites yet" : "Поки немає нічого, позначеного зірочкою",
+    "Files and folders you mark as favorite will show up here" : "Файли та каталоги із зірочкою з’являться тут",
+    "All files" : "Усі файли",
+    "List of your files and folders." : "Список ваших файлів та каталогів.",
+    "All folders" : "Усі каталоги",
+    "Personal Files" : "Приватні файли",
+    "List of your files and folders that are not shared." : "Перелік ваших файлів та каталогів, які не є у спільному доступі.",
+    "No personal files found" : "Приватні файли не знайдено",
+    "Files that are not shared will show up here." : "Тут показуватимуться файли, які не є у спільному доступі.",
     "List of recently modified files and folders." : "Список нещодавно змінених файлів та каталогів.",
     "No recently modified files" : "Відсутні файли із нещодавними змінами",
     "Files and folders you recently modified will show up here." : "Тут показуватимуться файли та каталоги, які було нещодавно змінено.",
-    "Toggle %1$s sublist" : "Перемкнути вкладений список %1$s",
-    "Toggle grid view" : "Перемкнути подання сіткою",
     "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
+    "Select all" : "Вибрати все",
     "Upload too large" : "Файл занадто великий",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер.",
     "Text file" : "Текстовий файл",
     "New text file.txt" : "Новий текстовий файл.txt",
-    "Storage invalid" : "Некоректне сховище",
-    "You can only favorite a single file or folder at a time" : "Одночасно можна вподобати лише один файл або каталог",
-    "Unlimited" : "Необмежено",
-    "Search users" : "Пошук користувачів",
-    "Cancel" : "Скасувати",
-    "%s used" : "%s використано",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "Використано %1$s із %2$s",
-    "Deleted files" : "Кошик",
-    "Shares" : "Спільне",
-    "Shared with others" : "Ви поділилися",
-    "Shared with you" : "Надано доступ вам",
-    "Shared by link" : "Доступ за посиланням",
-    "Deleted shares" : "Більше недоступні",
-    "Pending shares" : "Запити на доступ",
-    "Open folder {name}" : "Відкрити каталог {name}",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Через обмеження, пов'язані з потужністю, список не показується повністю. Файли показуватимуться, щойно ви рухатиметеся списком.",
-    "Search for an account" : "Пошук облікового запису",
-    "No files or folders have been deleted yet" : "Поки жодного каталогу чи файлу не було вилучено"
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Пряме посилання скопійовано (застосовується у разі, якщо користувач має доступ до ресурсу)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копіювати пряме посилання (користувачі мають мати доступ до цього файлу чи каталогу)",
+    "\"remote user\"" : "\"віддалений користувач\"",
+    "{newName} already exists." : "{newName} вже присутній.",
+    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" не дозволено всередині імени файлу.",
+    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" не дозволене ім'я файлу або каталогу.",
+    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" не дозволений тип файлу.",
+    "Filenames must not end with \"{segment}\"." : "Імена файлів не можуть закінчуватися на \"{segment}\".",
+    "Name cannot be empty" : "Ім'я не може бути порожнім",
+    "Another entry with the same name already exists" : "Ще один запис з таким ім'ям вже присутній.",
+    "Storage informations" : "Інформація про сховище",
+    "Open the files app settings" : "Перейти до налаштувань застосунку файлів",
+    "You might not have have permissions to view it, ask the sender to share it" : "Ймовірно у вас відсутні права на перегляд. Попросіть відправника поділитися доступом.",
+    "The files is locked" : "Файл заблоковано",
+    "Create new templates folder" : "Створіть новий каталог для шаблонів",
+    "Toggle %1$s sublist" : "Перемкнути вкладений список %1$s"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
