@@ -156,11 +156,20 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "文件已经添加或删除到您的<strong>收藏夹</strong> 中",
     "A file or folder has been <strong>changed</strong>" : "文件或文件夹已经被<strong>修改</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "一个收藏的文件或文件夹已经被<strong>修改</strong>",
+    "Failed to authorize" : "授权失败",
+    "Invalid folder path" : "无效文件夹路径",
+    "Folder not found" : "未找到文件夹",
     "Upload (max. %s)" : "上传 （最大 %s）",
+    "Files compatibility" : "文件兼容性",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允许限制文件名称以确保文件可以与所有客户端同步。默认状态下，所有POSIX（例如 Linux 或 macOS）系统有效的文件名都是被允许的。",
+    "Enforce Windows compatibility" : "强制 Windows 兼容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "这将阻止在 Windows 系统中无效的文件名称，比如使用保留字符。但这不会强制大小写敏感性兼容。",
     "Accept" : "接受",
     "Reject" : "拒绝",
     "Incoming ownership transfer from {user}" : "来自 {user} 的所有权转移",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您要接受 {path} 吗？\n\n注意：接受后转移过程可能长达1小时。",
+    "Ownership transfer denied" : "所有权转移被拒绝",
+    "Your ownership transfer of {path} was denied by {user}." : "你路径 {path} 下的文件所属权转移被 {user} 拒绝。",
     "Ownership transfer failed" : "所有权转移失败",
     "Your ownership transfer of {path} to {user} failed." : "您 {path} 的所有权向 {user} 转移失败。",
     "The ownership transfer of {path} from {user} failed." : "来自 {user} 的 {path} 的所有权转移失败。",
@@ -168,6 +177,7 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "您的 {path} 向 {user} 的所有权转移已完成。",
     "The ownership transfer of {path} from {user} has completed." : "来自 {user} 的 {path} 的所有权转移已完成。",
     "in %s" : "在 %s",
+    "Transferred from %1$s on %2$s" : "从 %1$s 转移至 %2$s",
     "File Management" : "文件管理",
     "Current directory path" : "当前文件目录",
     "Reload current directory" : "重新载入当前目录",
@@ -179,23 +189,25 @@ OC.L10N.register(
     "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
     "Toggle selection for file \"{displayName}\"" : "切换文件 “{displayName}” 的选择",
     "Toggle selection for folder \"{displayName}\"" : "切换文件夹 “{displayName}” 的选择",
+    "File is loading" : "正在加载文件",
+    "Folder is loading" : "正在加载文件夹",
     "Rename file" : "重命名文件",
-    "File name" : "文件名",
+    "Filename" : "文件名",
     "Folder name" : "文件夹名称",
     "This node is unavailable" : "此节点不可用",
-    "Download file {name}" : "下载文件 {name}",
-    "Invalid file name" : "无效文件名称",
-    "\"{name}\" is not an allowed filetype." : "“{name}”不是允许的文件类型",
-    "{newName} already exists." : "{newName}已经存在。",
-    "\"{char}\" is not allowed inside a file name." : "不允许文件名中包含 “{char}”",
-    "Name cannot be empty" : "名称不能为空",
-    "Another entry with the same name already exists" : "已经存在另一个使用该名称的条目",
+    "Another entry with the same name already exists." : "另一相同名称的条目已存在。",
+    "Invalid filename." : "无效文件名称。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已将“{oldName}”重命名为“{newName}”",
     "Could not rename \"{oldName}\", it does not exist any more" : "无法重命名“{fileName}”，此文件已经不存在",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名称「{newName}」在这个文件夹「{dir}」已经被使用。请选择其他名称。",
     "Could not rename \"{oldName}\"" : "无法重命名“{fileName}”",
+    "Clear filter" : "清除筛选",
+    "Type" : "类型",
+    "Active filters" : "已开启的过滤器",
+    "Remove filter" : "移除过滤条件",
     "Total rows summary" : "总行摘要",
     "Toggle selection for all files and folders" : "切换所有文件和文件夹 “{displayName}” 的选择",
+    "(selected)" : "（选中）",
     "\"{displayName}\" failed on some elements " : "“{displayName}”在某些元素上失败",
     "\"{displayName}\" batch action executed successfully" : "批量操作“{displayName}”运行成功",
     "{count} selected" : "已选中 {count}",
@@ -203,13 +215,17 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "带有按钮的列标题可进行排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出于性能考虑，此列表未完全呈现。文件将在您浏览列表时呈现。",
     "File not found" : "文件未找到",
-    "Storage informations" : "存储信息",
+    "Storage information" : "存储信息",
+    "Storage quota" : "存储配额",
     "{usedQuotaByte} used" : "{usedQuotaByte} 已使用",
     "{relative}% used" : "{relative}% 已使用",
     "Could not refresh storage stats" : "无法刷新存储统计数据",
     "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
     "Create" : "创建",
-    "A file or folder with that name already exists." : "相同文件夹或文件已存在。",
+    "This name is already in use." : "此名称已被使用。",
+    "Fill template fields" : "填写模板字段",
+    "Submitting fields…" : "提交字段...",
+    "Submit" : "使用",
     "Transfer ownership of a file or folder" : "转移文件或文件夹的所有权",
     "Choose file or folder to transfer" : "选择要转移的文件或文件夹",
     "Change" : "修改",
@@ -234,10 +250,12 @@ OC.L10N.register(
     "Shared" : "已共享",
     "Switch to list view" : "切换为列表视图",
     "Switch to grid view" : "切换到网格视图",
+    "Upload was cancelled by user" : "用户已取消上传",
     "Error during upload: {message}" : "上传时发生错误: {message}",
     "Error during upload, status code {status}" : "上传时发生错误，状态码 {status}",
     "Unknown error during upload" : "上传时发生未知错误",
-    "Open the files app settings" : "打开文件设置",
+    "Filter filenames…" : "过滤文件名...",
+    "Views" : "视图",
     "Files settings" : "文件设置",
     "File cannot be accessed" : "文件无法访问",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到该文件，或是您没有查看该文件的权限。请要求发送者分享它。",
@@ -248,6 +266,7 @@ OC.L10N.register(
     "Show hidden files" : "显示隐藏文件",
     "Crop image previews" : "裁剪图片预览",
     "Enable the grid view" : "启用网格视图",
+    "Enable folder tree" : "启用文件夹树",
     "Additional settings" : "其他设置",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -263,16 +282,21 @@ OC.L10N.register(
     "Creating file" : "正在创建文件",
     "Blank" : "空白",
     "Unable to create new file from template" : "无法从模板创建新文件",
+    "Deletion cancelled" : "已取消删除",
     "Delete permanently" : "彻底删除",
     "Delete and unshare" : "删除并取消分享",
     "Leave these shares" : "离开此分享",
     "Disconnect storages" : "断开与存储空间的连接",
     "Delete files" : "删除文件",
     "Delete folders" : "删除文件夹",
-    "You are about to delete {count} items." : "您将删除 {count} 个项目",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您正要永久删除 {count} 个项目"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您正要删除 {count} 个项目"],
     "Confirm deletion" : "确认删除",
     "Cancel" : "取消",
-    "Deletion cancelled" : "已取消删除",
+    "Edit file locally" : "本地编辑",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "文件应在本地打开。如果你看不到任何文件被打开，请先确保在你的电脑中已安装相关的桌面客户端。",
+    "Retry local edit" : "重试本地编辑",
+    "Edit online" : "在线编辑",
     "Destination is not a folder" : "目标不是一个文件夹",
     "This file/folder is already in that directory" : "该文件/文件夹已经存在与该目录中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "你无法将文件/文件夹移动至其自身或子文件夹中",
@@ -285,15 +309,29 @@ OC.L10N.register(
     "Choose destination" : "选择目标路径",
     "Copy to {target}" : "复制到 {target}",
     "Move to {target}" : "移动到 {target}",
-    "Cancelled move or copy operation" : "已取消移动或复制操作",
     "Move or copy operation failed" : "移动或复制失败",
+    "Cancelled move or copy of \"{filename}\"." : "取消移动或复制“{filename}”。",
+    "Cancelled move or copy operation" : "已取消移动或复制操作",
     "Open folder {displayName}" : "打开文件夹{displayName}",
     "Open in Files" : "在文件中打开",
     "Open details" : "打开详情",
+    "Today" : "今日",
+    "Last 7 days" : "过去 7 天",
+    "Last 30 days" : "过去 30 天",
+    "This year ({year})" : "今年（{year}）",
+    "Last year ({year})" : "去年（{year}）",
+    "Documents" : "文档",
+    "Spreadsheets" : "表格",
+    "Presentations" : "幻灯片",
+    "PDFs" : "PDF",
+    "Folders" : "文件夹",
+    "Audio" : "声音提醒",
+    "Photos and images" : "照片和影像",
+    "Videos" : "视频",
+    "New folder creation cancelled" : "取消创建新文件夹",
     "Created new folder \"{name}\"" : "创建了新文件夹「{name}」",
-    "Filename" : "文件名",
     "Unable to initialize the templates directory" : "无法初始化模板目录",
-    "Create new templates folder" : "新建模板文件夹",
+    "Create templates folder" : "创建模板文件夹",
     "Templates" : "模板",
     "New template folder" : "新建模板文件夹",
     "In folder" : "文件夹内",
@@ -316,11 +354,17 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 个文件夹及 {folderCount} 个文件夹"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 个文件及 1 个文件夹"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} 个文件及 {folderCount} 个文件夹",
+    "Filename must not be empty." : "文件名不能为空。",
+    "\"{char}\" is not allowed inside a filename." : "文件名中不允许出现 “{char}”",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "“{segment}” 是一个保留名称，不允许用在文件名中。",
+    "\"{extension}\" is not an allowed filetype." : "“{extension}” 文件类型不被允许。",
+    "Filenames must not end with \"{extension}\"." : "文件名不能以 “{extension}” 结尾。",
     "List of favorites files and folders." : "收藏文件和文件夹列表",
     "No favorites yet" : "暂无收藏",
     "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
     "All files" : "全部文件",
     "List of your files and folders." : "您的文件与文件件列表。",
+    "All folders" : "所有文件夹",
     "Personal Files" : "个人文件",
     "List of your files and folders that are not shared." : "尚未分享的文件与文件夹",
     "No personal files found" : "找不到个人文件",
@@ -336,29 +380,19 @@ OC.L10N.register(
     "New text file.txt" : "新建文本文档.txt",
     "Direct link was copied (only works for users who have access to this file/folder)" : "已复制直链（仅适用于有权访问此文件/文件夹的用户）",
     "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
-    "You can only favorite a single file or folder at a time" : "您一次只能收藏一个文件或文件夹",
-    "This file has the tag {tag}" : "这个文件有 {tag} 标签",
-    "This file has the tags {firstTags} and {lastTag}" : "这个文件有 {firstTags} 和 {lastTag} 标签",
     "\"remote user\"" : "“远程用户”",
-    "Select the row for {displayName}" : "选择 {displayName} 的行",
-    "Open folder {name}" : "打开文件夹 {name}",
-    "Unselect all" : "取消全选",
-    "ascending" : "升序",
-    "descending" : "降序",
-    "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序列表",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "因为性能原因，该列表没有完全加载。这些文件将会在您浏览列表的时候加载。",
-    "Search for an account" : "搜索一个账户",
-    "Choose" : "选择",
-    "No files or folders have been deleted yet" : "尚未删除任何文件或文件夹",
+    "{newName} already exists." : "{newName}已经存在。",
+    "\"{segment}\" is not allowed inside a filename." : "文件名不允许使用“{segment}”。",
+    "\"{segment}\" is a forbidden file or folder name." : "文件夹或文件名禁止使用“{segment}”。",
+    "\"{segment}\" is not an allowed filetype." : "文件类型不允许使用“{segment}”。",
+    "Filenames must not end with \"{segment}\"." : "文件名不能以“{segment}”结尾。",
+    "Name cannot be empty" : "名称不能为空",
+    "Another entry with the same name already exists" : "已经存在另一个使用该名称的条目",
+    "Storage informations" : "存储信息",
+    "Open the files app settings" : "打开文件设置",
     "You might not have have permissions to view it, ask the sender to share it" : "您可能没有权限浏览它，请要求发送者分享它",
-    "Set up templates folder" : "设置模板文件夹",
-    "Toggle %1$s sublist" : "切换 %1$s 子列表",
-    "Toggle grid view" : "切换网格视图",
-    "Shares" : "共享",
-    "Shared with others" : "已与他人共享",
-    "Shared with you" : "与您共享的",
-    "Deleted shares" : "已删除的共享",
-    "Pending shares" : "待定共享",
-    "The files is locked" : "文件已锁定"
+    "The files is locked" : "文件已锁定",
+    "Create new templates folder" : "新建模板文件夹",
+    "Toggle %1$s sublist" : "切换 %1$s 子列表"
 },
 "nplurals=1; plural=0;");
